
# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.cancellation_api import CancellationApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from channelengine_channel_api_client.api.cancellation_api import CancellationApi
from channelengine_channel_api_client.api.order_api import OrderApi
from channelengine_channel_api_client.api.product_api import ProductApi
from channelengine_channel_api_client.api.return_api import ReturnApi
from channelengine_channel_api_client.api.shipment_api import ShipmentApi



"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.13.0
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from channelengine_channel_api_client.api_client import ApiClient, Endpoint as _Endpoint
from channelengine_channel_api_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from channelengine_channel_api_client.model.api_response import ApiResponse
from channelengine_channel_api_client.model.channel_order_request import ChannelOrderRequest


class OrderApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.order_create_endpoint = _Endpoint(
            settings={
                'response_type': (ApiResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/v2/orders',
                'operation_id': 'order_create',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'channel_order_request',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'channel_order_request':
                        (ChannelOrderRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'channel_order_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json-patch+json',
                    'application/json',
                    'application/*+json'
                ]
            },
            api_client=api_client
        )
        self.order_invoice_endpoint = _Endpoint(
            settings={
                'response_type': (file,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/v2/orders/{merchantOrderNo}/invoice',
                'operation_id': 'order_invoice',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'merchant_order_no',
                    'use_customer_culture',
                ],
                'required': [
                    'merchant_order_no',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'merchant_order_no':
                        (str,),
                    'use_customer_culture':
                        (bool,),
                },
                'attribute_map': {
                    'merchant_order_no': 'merchantOrderNo',
                    'use_customer_culture': 'useCustomerCulture',
                },
                'location_map': {
                    'merchant_order_no': 'path',
                    'use_customer_culture': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/pdf',
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.order_packing_slip_endpoint = _Endpoint(
            settings={
                'response_type': (file,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/v2/orders/{merchantOrderNo}/packingslip',
                'operation_id': 'order_packing_slip',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'merchant_order_no',
                    'use_customer_culture',
                ],
                'required': [
                    'merchant_order_no',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'merchant_order_no':
                        (str,),
                    'use_customer_culture':
                        (bool,),
                },
                'attribute_map': {
                    'merchant_order_no': 'merchantOrderNo',
                    'use_customer_culture': 'useCustomerCulture',
                },
                'location_map': {
                    'merchant_order_no': 'path',
                    'use_customer_culture': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/pdf',
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def order_create(
        self,
        **kwargs
    ):
        """Create Order.  # noqa: E501

        Create a new order in ChannelEngine.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.order_create(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            channel_order_request (ChannelOrderRequest): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ApiResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.order_create_endpoint.call_with_http_info(**kwargs)

    def order_invoice(
        self,
        merchant_order_no,
        **kwargs
    ):
        """Download Invoice.  # noqa: E501

        Generates the ChannelEngine VAT invoice for this order in PDF.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.order_invoice(merchant_order_no, async_req=True)
        >>> result = thread.get()

        Args:
            merchant_order_no (str): The unique order reference as used by the merchant.

        Keyword Args:
            use_customer_culture (bool): Generate the invoice in the billing address' country's language.. [optional] if omitted the server will use the default value of False
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            file
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['merchant_order_no'] = \
            merchant_order_no
        return self.order_invoice_endpoint.call_with_http_info(**kwargs)

    def order_packing_slip(
        self,
        merchant_order_no,
        **kwargs
    ):
        """Download Packing Slip.  # noqa: E501

        Generates the ChannelEngine packing slip for this order in PDF.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.order_packing_slip(merchant_order_no, async_req=True)
        >>> result = thread.get()

        Args:
            merchant_order_no (str): The unique order reference as used by the merchant.

        Keyword Args:
            use_customer_culture (bool): Generate the invoice in the billing address' country's language.. [optional] if omitted the server will use the default value of False
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            file
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['merchant_order_no'] = \
            merchant_order_no
        return self.order_packing_slip_endpoint.call_with_http_info(**kwargs)




"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.13.0
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from channelengine_channel_api_client.api_client import ApiClient, Endpoint as _Endpoint
from channelengine_channel_api_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from channelengine_channel_api_client.model.api_response import ApiResponse
from channelengine_channel_api_client.model.channel_processed_changes_request import ChannelProcessedChangesRequest
from channelengine_channel_api_client.model.collection_changes_of_channel_product_changes_response import CollectionChangesOfChannelProductChangesResponse
from channelengine_channel_api_client.model.collection_of_channel_offer_response import CollectionOfChannelOfferResponse
from channelengine_channel_api_client.model.data_changes_product_type import DataChangesProductType


class ProductApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.product_acknowledge_data_changes_endpoint = _Endpoint(
            settings={
                'response_type': (ApiResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/v2/products/data',
                'operation_id': 'product_acknowledge_data_changes',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'channel_processed_changes_request',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'channel_processed_changes_request':
                        (ChannelProcessedChangesRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'channel_processed_changes_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json-patch+json',
                    'application/json',
                    'application/*+json'
                ]
            },
            api_client=api_client
        )
        self.product_acknowledge_offer_changes_endpoint = _Endpoint(
            settings={
                'response_type': (ApiResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/v2/products/offers',
                'operation_id': 'product_acknowledge_offer_changes',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'key_is_mpn',
                    'request_body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'key_is_mpn':
                        (bool,),
                    'request_body':
                        ([str],),
                },
                'attribute_map': {
                    'key_is_mpn': 'keyIsMpn',
                },
                'location_map': {
                    'key_is_mpn': 'query',
                    'request_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json-patch+json',
                    'application/json',
                    'application/*+json'
                ]
            },
            api_client=api_client
        )
        self.product_get_data_changes_endpoint = _Endpoint(
            settings={
                'response_type': (CollectionChangesOfChannelProductChangesResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/v2/products/data',
                'operation_id': 'product_get_data_changes',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'max_count',
                    'strip_html',
                    'page',
                    'page_size',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'max_count':
                        (int,),
                    'strip_html':
                        (bool,),
                    'page':
                        (int,),
                    'page_size':
                        (int,),
                },
                'attribute_map': {
                    'max_count': 'maxCount',
                    'strip_html': 'stripHtml',
                    'page': 'page',
                    'page_size': 'pageSize',
                },
                'location_map': {
                    'max_count': 'query',
                    'strip_html': 'query',
                    'page': 'query',
                    'page_size': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.product_get_data_changes_full_endpoint = _Endpoint(
            settings={
                'response_type': (CollectionChangesOfChannelProductChangesResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/v2/products/data/full',
                'operation_id': 'product_get_data_changes_full',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'product_type',
                    'max_count',
                    'strip_html',
                    'page',
                    'page_size',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'product_type':
                        (DataChangesProductType,),
                    'max_count':
                        (int,),
                    'strip_html':
                        (bool,),
                    'page':
                        (int,),
                    'page_size':
                        (int,),
                },
                'attribute_map': {
                    'product_type': 'productType',
                    'max_count': 'maxCount',
                    'strip_html': 'stripHtml',
                    'page': 'page',
                    'page_size': 'pageSize',
                },
                'location_map': {
                    'product_type': 'query',
                    'max_count': 'query',
                    'strip_html': 'query',
                    'page': 'query',
                    'page_size': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.product_get_offer_changes_endpoint = _Endpoint(
            settings={
                'response_type': (CollectionOfChannelOfferResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/v2/products/offers',
                'operation_id': 'product_get_offer_changes',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'page',
                    'page_size',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'page':
                        (int,),
                    'page_size':
                        (int,),
                },
                'attribute_map': {
                    'page': 'page',
                    'page_size': 'pageSize',
                },
                'location_map': {
                    'page': 'query',
                    'page_size': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def product_acknowledge_data_changes(
        self,
        **kwargs
    ):
        """Acknowledge Product Data Changes.  # noqa: E501

        This endpoint should be called after a call to GET 'v2/products/data'. After a call to<br />this endpoint ChannelEngine 'knows' which products are known to the channel (and the last<br />time they have been updated) and is therefore able to only return the products<br />that really have changed since the last call to POST 'v2/products/data'.<br />The supplied ChannelReturnNo will be saved<br />in our database and is supposed to be unique, the 'Updated' and 'Removed'<br />fields consist of ChannelReferences which are sent in a previous call<br />within the field 'Created'.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.product_acknowledge_data_changes(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            channel_processed_changes_request (ChannelProcessedChangesRequest): The merchant references of the products which have been<br /> successfully created, updated or deleted (after a call to 'GetDataChanges').. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ApiResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.product_acknowledge_data_changes_endpoint.call_with_http_info(**kwargs)

    def product_acknowledge_offer_changes(
        self,
        **kwargs
    ):
        """Acknowledge Product Offer Changes.  # noqa: E501

        After a call to GET 'v2/products/offers' this endpoint should be called with the<br />ChannelProductNo of the products that are successfully updated.<br />Please see 'v2/products/data' and 'v2/products/data' for documentation.<br />In advanced cases, the MerchantProductNo is used for this.<br />In that case, bool keyIsMpn should be true.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.product_acknowledge_offer_changes(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            key_is_mpn (bool): If set to true, changes has to be a list of merchant references instead of channel references.. [optional] if omitted the server will use the default value of False
            request_body ([str]): The channel references of the updated products.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ApiResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.product_acknowledge_offer_changes_endpoint.call_with_http_info(**kwargs)

    def product_get_data_changes(
        self,
        **kwargs
    ):
        """Get Product Data Changes.  # noqa: E501

        Get all products which have changes since the post http call to POST 'v2/products/data'.<br />The response contains the products which should be created, updated or removed from the channel.<br />After the products have been received and processed successfully 'v2/products/data' should<br />be called with the merchant references of the products which have been processed (see POST 'v2/products/data').<br />ChannelEngine will save this information to make sure that the next call to GET 'v2/products/data' only returns the<br />products that really have changes (and therefore should be created, updated or deleted).<br />A channel willing to integrate with channelengine should therefore only do the following things:<br /> 1. Periodically poll 'v2/products/data' for changes.<br /> 2. If any products are returned, save, update or remove these products.<br /> 3. Send the merchant references of the products that have succesfully been processed<br /> in step 2 to POST 'v2/products/data'.<br /> <br />These three simple steps will make sure that the products on the channel will be synchronized<br />with the products on ChannelEngine. ChannelEngine will use the API key to determine the customer<br />whose products should be returned. Note that child products are only returned if their parent product<br />has been acknowledged in a previous transaction. This way ChannelEngine knows the value of<br />'ChannelParentReference'.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.product_get_data_changes(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            max_count (int): Optional - limit the amount of products returned for each field<br /> (ToBeCreated, ToBeUpdated, ToBeRemoved) to this number.. [optional]
            strip_html (bool): Optional - strips html by default on all fields. [optional] if omitted the server will use the default value of True
            page (int): [optional]
            page_size (int): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            CollectionChangesOfChannelProductChangesResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.product_get_data_changes_endpoint.call_with_http_info(**kwargs)

    def product_get_data_changes_full(
        self,
        **kwargs
    ):
        """Get Product Data Changes with an optional product type filter. If you select product type products will be filtered by it.  If you won't pass product type you will get products with types: CHILD, PARENT, GRANDPARENT, SINGLE  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.product_get_data_changes_full(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            product_type (DataChangesProductType): Optional - Type of products. [optional]
            max_count (int): Optional - limit the amount of products returned for each field<br /> (ToBeCreated, ToBeUpdated, ToBeRemoved) to this number.. [optional]
            strip_html (bool): Optional - strips html by default on all fields. [optional] if omitted the server will use the default value of True
            page (int): [optional]
            page_size (int): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            CollectionChangesOfChannelProductChangesResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.product_get_data_changes_full_endpoint.call_with_http_info(**kwargs)

    def product_get_offer_changes(
        self,
        **kwargs
    ):
        """Get Product Offer Changes.  # noqa: E501

        GET 'v2/products/offers' and POST 'v2/products/offers' closely resemble GET 'v2/products/data' and POST 'v2/products/data'. See the 'v2/products/data'<br />endpoints for documentation. The difference between both endpoints is that 'v2/products/offers' only returns Price and Stock updates and can (and should)<br />therefore be called more often to keep this information (which might change frequently) up to date.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.product_get_offer_changes(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            page (int): [optional]
            page_size (int): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            CollectionOfChannelOfferResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.product_get_offer_changes_endpoint.call_with_http_info(**kwargs)




# coding: utf-8

"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.9.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from channelengine_channel_api_client.configuration import Configuration


class ChannelReturnRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'channel_order_no': 'str',
        'merchant_order_no': 'str',
        'channel_reference': 'str',
        'key_is_merchant_order_no': 'bool',
        'key_is_merchant_product_no': 'bool',
        'lines': 'list[ChannelReturnLineRequest]',
        'id': 'int',
        'reason': 'ReturnReason',
        'customer_comment': 'str',
        'merchant_comment': 'str',
        'refund_incl_vat': 'float',
        'refund_excl_vat': 'float'
    }

    attribute_map = {
        'channel_order_no': 'ChannelOrderNo',
        'merchant_order_no': 'MerchantOrderNo',
        'channel_reference': 'ChannelReference',
        'key_is_merchant_order_no': 'KeyIsMerchantOrderNo',
        'key_is_merchant_product_no': 'KeyIsMerchantProductNo',
        'lines': 'Lines',
        'id': 'Id',
        'reason': 'Reason',
        'customer_comment': 'CustomerComment',
        'merchant_comment': 'MerchantComment',
        'refund_incl_vat': 'RefundInclVat',
        'refund_excl_vat': 'RefundExclVat'
    }

    def __init__(self, channel_order_no=None, merchant_order_no=None, channel_reference=None, key_is_merchant_order_no=None, key_is_merchant_product_no=None, lines=None, id=None, reason=None, customer_comment=None, merchant_comment=None, refund_incl_vat=None, refund_excl_vat=None, local_vars_configuration=None):  # noqa: E501
        """ChannelReturnRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._channel_order_no = None
        self._merchant_order_no = None
        self._channel_reference = None
        self._key_is_merchant_order_no = None
        self._key_is_merchant_product_no = None
        self._lines = None
        self._id = None
        self._reason = None
        self._customer_comment = None
        self._merchant_comment = None
        self._refund_incl_vat = None
        self._refund_excl_vat = None
        self.discriminator = None

        self.channel_order_no = channel_order_no
        self.merchant_order_no = merchant_order_no
        self.channel_reference = channel_reference
        if key_is_merchant_order_no is not None:
            self.key_is_merchant_order_no = key_is_merchant_order_no
        if key_is_merchant_product_no is not None:
            self.key_is_merchant_product_no = key_is_merchant_product_no
        self.lines = lines
        if id is not None:
            self.id = id
        if reason is not None:
            self.reason = reason
        self.customer_comment = customer_comment
        self.merchant_comment = merchant_comment
        if refund_incl_vat is not None:
            self.refund_incl_vat = refund_incl_vat
        if refund_excl_vat is not None:
            self.refund_excl_vat = refund_excl_vat

    @property
    def channel_order_no(self):
        """Gets the channel_order_no of this ChannelReturnRequest.  # noqa: E501

        The unique order reference used by the Channel.  # noqa: E501

        :return: The channel_order_no of this ChannelReturnRequest.  # noqa: E501
        :rtype: str
        """
        return self._channel_order_no

    @channel_order_no.setter
    def channel_order_no(self, channel_order_no):
        """Sets the channel_order_no of this ChannelReturnRequest.

        The unique order reference used by the Channel.  # noqa: E501

        :param channel_order_no: The channel_order_no of this ChannelReturnRequest.  # noqa: E501
        :type channel_order_no: str
        """

        self._channel_order_no = channel_order_no

    @property
    def merchant_order_no(self):
        """Gets the merchant_order_no of this ChannelReturnRequest.  # noqa: E501

        The unique order reference used by the Merchant (sku).  # noqa: E501

        :return: The merchant_order_no of this ChannelReturnRequest.  # noqa: E501
        :rtype: str
        """
        return self._merchant_order_no

    @merchant_order_no.setter
    def merchant_order_no(self, merchant_order_no):
        """Sets the merchant_order_no of this ChannelReturnRequest.

        The unique order reference used by the Merchant (sku).  # noqa: E501

        :param merchant_order_no: The merchant_order_no of this ChannelReturnRequest.  # noqa: E501
        :type merchant_order_no: str
        """

        self._merchant_order_no = merchant_order_no

    @property
    def channel_reference(self):
        """Gets the channel_reference of this ChannelReturnRequest.  # noqa: E501

        The unique return reference used by the Channel.  # noqa: E501

        :return: The channel_reference of this ChannelReturnRequest.  # noqa: E501
        :rtype: str
        """
        return self._channel_reference

    @channel_reference.setter
    def channel_reference(self, channel_reference):
        """Sets the channel_reference of this ChannelReturnRequest.

        The unique return reference used by the Channel.  # noqa: E501

        :param channel_reference: The channel_reference of this ChannelReturnRequest.  # noqa: E501
        :type channel_reference: str
        """
        if self.local_vars_configuration.client_side_validation and channel_reference is None:  # noqa: E501
            raise ValueError("Invalid value for `channel_reference`, must not be `None`")  # noqa: E501

        self._channel_reference = channel_reference

    @property
    def key_is_merchant_order_no(self):
        """Gets the key_is_merchant_order_no of this ChannelReturnRequest.  # noqa: E501

        Optional. Is the MON used as key for the order (default value is false).  # noqa: E501

        :return: The key_is_merchant_order_no of this ChannelReturnRequest.  # noqa: E501
        :rtype: bool
        """
        return self._key_is_merchant_order_no

    @key_is_merchant_order_no.setter
    def key_is_merchant_order_no(self, key_is_merchant_order_no):
        """Sets the key_is_merchant_order_no of this ChannelReturnRequest.

        Optional. Is the MON used as key for the order (default value is false).  # noqa: E501

        :param key_is_merchant_order_no: The key_is_merchant_order_no of this ChannelReturnRequest.  # noqa: E501
        :type key_is_merchant_order_no: bool
        """

        self._key_is_merchant_order_no = key_is_merchant_order_no

    @property
    def key_is_merchant_product_no(self):
        """Gets the key_is_merchant_product_no of this ChannelReturnRequest.  # noqa: E501

        Optional. Is the MPN used as key for the product (default value is false).  # noqa: E501

        :return: The key_is_merchant_product_no of this ChannelReturnRequest.  # noqa: E501
        :rtype: bool
        """
        return self._key_is_merchant_product_no

    @key_is_merchant_product_no.setter
    def key_is_merchant_product_no(self, key_is_merchant_product_no):
        """Sets the key_is_merchant_product_no of this ChannelReturnRequest.

        Optional. Is the MPN used as key for the product (default value is false).  # noqa: E501

        :param key_is_merchant_product_no: The key_is_merchant_product_no of this ChannelReturnRequest.  # noqa: E501
        :type key_is_merchant_product_no: bool
        """

        self._key_is_merchant_product_no = key_is_merchant_product_no

    @property
    def lines(self):
        """Gets the lines of this ChannelReturnRequest.  # noqa: E501


        :return: The lines of this ChannelReturnRequest.  # noqa: E501
        :rtype: list[ChannelReturnLineRequest]
        """
        return self._lines

    @lines.setter
    def lines(self, lines):
        """Sets the lines of this ChannelReturnRequest.


        :param lines: The lines of this ChannelReturnRequest.  # noqa: E501
        :type lines: list[ChannelReturnLineRequest]
        """
        if self.local_vars_configuration.client_side_validation and lines is None:  # noqa: E501
            raise ValueError("Invalid value for `lines`, must not be `None`")  # noqa: E501

        self._lines = lines

    @property
    def id(self):
        """Gets the id of this ChannelReturnRequest.  # noqa: E501

        The unique return reference used by ChannelEngine.  # noqa: E501

        :return: The id of this ChannelReturnRequest.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ChannelReturnRequest.

        The unique return reference used by ChannelEngine.  # noqa: E501

        :param id: The id of this ChannelReturnRequest.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def reason(self):
        """Gets the reason of this ChannelReturnRequest.  # noqa: E501

        The reason code of the return.  # noqa: E501

        :return: The reason of this ChannelReturnRequest.  # noqa: E501
        :rtype: ReturnReason
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this ChannelReturnRequest.

        The reason code of the return.  # noqa: E501

        :param reason: The reason of this ChannelReturnRequest.  # noqa: E501
        :type reason: ReturnReason
        """

        self._reason = reason

    @property
    def customer_comment(self):
        """Gets the customer_comment of this ChannelReturnRequest.  # noqa: E501

        Optional. Comment of customer on the (reason of) the return.  # noqa: E501

        :return: The customer_comment of this ChannelReturnRequest.  # noqa: E501
        :rtype: str
        """
        return self._customer_comment

    @customer_comment.setter
    def customer_comment(self, customer_comment):
        """Sets the customer_comment of this ChannelReturnRequest.

        Optional. Comment of customer on the (reason of) the return.  # noqa: E501

        :param customer_comment: The customer_comment of this ChannelReturnRequest.  # noqa: E501
        :type customer_comment: str
        """
        if (self.local_vars_configuration.client_side_validation and
                customer_comment is not None and len(customer_comment) > 4001):
            raise ValueError("Invalid value for `customer_comment`, length must be less than or equal to `4001`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                customer_comment is not None and len(customer_comment) < 0):
            raise ValueError("Invalid value for `customer_comment`, length must be greater than or equal to `0`")  # noqa: E501

        self._customer_comment = customer_comment

    @property
    def merchant_comment(self):
        """Gets the merchant_comment of this ChannelReturnRequest.  # noqa: E501

        Optional. Comment of merchant on the return.  # noqa: E501

        :return: The merchant_comment of this ChannelReturnRequest.  # noqa: E501
        :rtype: str
        """
        return self._merchant_comment

    @merchant_comment.setter
    def merchant_comment(self, merchant_comment):
        """Sets the merchant_comment of this ChannelReturnRequest.

        Optional. Comment of merchant on the return.  # noqa: E501

        :param merchant_comment: The merchant_comment of this ChannelReturnRequest.  # noqa: E501
        :type merchant_comment: str
        """
        if (self.local_vars_configuration.client_side_validation and
                merchant_comment is not None and len(merchant_comment) > 4001):
            raise ValueError("Invalid value for `merchant_comment`, length must be less than or equal to `4001`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                merchant_comment is not None and len(merchant_comment) < 0):
            raise ValueError("Invalid value for `merchant_comment`, length must be greater than or equal to `0`")  # noqa: E501

        self._merchant_comment = merchant_comment

    @property
    def refund_incl_vat(self):
        """Gets the refund_incl_vat of this ChannelReturnRequest.  # noqa: E501

        Refund amount incl. VAT.  # noqa: E501

        :return: The refund_incl_vat of this ChannelReturnRequest.  # noqa: E501
        :rtype: float
        """
        return self._refund_incl_vat

    @refund_incl_vat.setter
    def refund_incl_vat(self, refund_incl_vat):
        """Sets the refund_incl_vat of this ChannelReturnRequest.

        Refund amount incl. VAT.  # noqa: E501

        :param refund_incl_vat: The refund_incl_vat of this ChannelReturnRequest.  # noqa: E501
        :type refund_incl_vat: float
        """
        if (self.local_vars_configuration.client_side_validation and
                refund_incl_vat is not None and refund_incl_vat < 0):  # noqa: E501
            raise ValueError("Invalid value for `refund_incl_vat`, must be a value greater than or equal to `0`")  # noqa: E501

        self._refund_incl_vat = refund_incl_vat

    @property
    def refund_excl_vat(self):
        """Gets the refund_excl_vat of this ChannelReturnRequest.  # noqa: E501

        Refund amount excl. VAT.  # noqa: E501

        :return: The refund_excl_vat of this ChannelReturnRequest.  # noqa: E501
        :rtype: float
        """
        return self._refund_excl_vat

    @refund_excl_vat.setter
    def refund_excl_vat(self, refund_excl_vat):
        """Sets the refund_excl_vat of this ChannelReturnRequest.

        Refund amount excl. VAT.  # noqa: E501

        :param refund_excl_vat: The refund_excl_vat of this ChannelReturnRequest.  # noqa: E501
        :type refund_excl_vat: float
        """
        if (self.local_vars_configuration.client_side_validation and
                refund_excl_vat is not None and refund_excl_vat < 0):  # noqa: E501
            raise ValueError("Invalid value for `refund_excl_vat`, must be a value greater than or equal to `0`")  # noqa: E501

        self._refund_excl_vat = refund_excl_vat

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChannelReturnRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChannelReturnRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.9.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from channelengine_channel_api_client.configuration import Configuration


class ChannelProductExtraDataItemResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'key': 'str',
        'value': 'str',
        'type': 'ExtraDataType',
        'is_public': 'bool'
    }

    attribute_map = {
        'key': 'Key',
        'value': 'Value',
        'type': 'Type',
        'is_public': 'IsPublic'
    }

    def __init__(self, key=None, value=None, type=None, is_public=None, local_vars_configuration=None):  # noqa: E501
        """ChannelProductExtraDataItemResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._key = None
        self._value = None
        self._type = None
        self._is_public = None
        self.discriminator = None

        self.key = key
        self.value = value
        if type is not None:
            self.type = type
        if is_public is not None:
            self.is_public = is_public

    @property
    def key(self):
        """Gets the key of this ChannelProductExtraDataItemResponse.  # noqa: E501

        Name of the extra data field.  # noqa: E501

        :return: The key of this ChannelProductExtraDataItemResponse.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this ChannelProductExtraDataItemResponse.

        Name of the extra data field.  # noqa: E501

        :param key: The key of this ChannelProductExtraDataItemResponse.  # noqa: E501
        :type key: str
        """
        if (self.local_vars_configuration.client_side_validation and
                key is not None and len(key) > 100):
            raise ValueError("Invalid value for `key`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                key is not None and len(key) < 0):
            raise ValueError("Invalid value for `key`, length must be greater than or equal to `0`")  # noqa: E501

        self._key = key

    @property
    def value(self):
        """Gets the value of this ChannelProductExtraDataItemResponse.  # noqa: E501

        Value of the extra data field.  # noqa: E501

        :return: The value of this ChannelProductExtraDataItemResponse.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this ChannelProductExtraDataItemResponse.

        Value of the extra data field.  # noqa: E501

        :param value: The value of this ChannelProductExtraDataItemResponse.  # noqa: E501
        :type value: str
        """

        self._value = value

    @property
    def type(self):
        """Gets the type of this ChannelProductExtraDataItemResponse.  # noqa: E501

        Type of the extra data field.  # noqa: E501

        :return: The type of this ChannelProductExtraDataItemResponse.  # noqa: E501
        :rtype: ExtraDataType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ChannelProductExtraDataItemResponse.

        Type of the extra data field.  # noqa: E501

        :param type: The type of this ChannelProductExtraDataItemResponse.  # noqa: E501
        :type type: ExtraDataType
        """

        self._type = type

    @property
    def is_public(self):
        """Gets the is_public of this ChannelProductExtraDataItemResponse.  # noqa: E501

        Add this field to the export of the product feed to the channel.  # noqa: E501

        :return: The is_public of this ChannelProductExtraDataItemResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_public

    @is_public.setter
    def is_public(self, is_public):
        """Sets the is_public of this ChannelProductExtraDataItemResponse.

        Add this field to the export of the product feed to the channel.  # noqa: E501

        :param is_public: The is_public of this ChannelProductExtraDataItemResponse.  # noqa: E501
        :type is_public: bool
        """

        self._is_public = is_public

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChannelProductExtraDataItemResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChannelProductExtraDataItemResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.9.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from channelengine_channel_api_client.configuration import Configuration


class ChannelProductResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'parent_channel_product_no': 'str',
        'grandparent_channel_product_no': 'str',
        'mapped_fields': 'dict(str, str)',
        'extra_data': 'list[ChannelProductExtraDataItemResponse]',
        'name': 'str',
        'description': 'str',
        'brand': 'str',
        'size': 'str',
        'color': 'str',
        'ean': 'str',
        'manufacturer_product_number': 'str',
        'merchant_product_no': 'str',
        'stock': 'int',
        'price': 'float',
        'msrp': 'float',
        'purchase_price': 'float',
        'vat_rate_type': 'VatRateType',
        'shipping_cost': 'float',
        'shipping_time': 'str',
        'url': 'str',
        'image_url': 'str',
        'extra_image_url1': 'str',
        'extra_image_url2': 'str',
        'extra_image_url3': 'str',
        'extra_image_url4': 'str',
        'extra_image_url5': 'str',
        'extra_image_url6': 'str',
        'extra_image_url7': 'str',
        'extra_image_url8': 'str',
        'extra_image_url9': 'str',
        'category_trail': 'str'
    }

    attribute_map = {
        'id': 'Id',
        'parent_channel_product_no': 'ParentChannelProductNo',
        'grandparent_channel_product_no': 'GrandparentChannelProductNo',
        'mapped_fields': 'MappedFields',
        'extra_data': 'ExtraData',
        'name': 'Name',
        'description': 'Description',
        'brand': 'Brand',
        'size': 'Size',
        'color': 'Color',
        'ean': 'Ean',
        'manufacturer_product_number': 'ManufacturerProductNumber',
        'merchant_product_no': 'MerchantProductNo',
        'stock': 'Stock',
        'price': 'Price',
        'msrp': 'MSRP',
        'purchase_price': 'PurchasePrice',
        'vat_rate_type': 'VatRateType',
        'shipping_cost': 'ShippingCost',
        'shipping_time': 'ShippingTime',
        'url': 'Url',
        'image_url': 'ImageUrl',
        'extra_image_url1': 'ExtraImageUrl1',
        'extra_image_url2': 'ExtraImageUrl2',
        'extra_image_url3': 'ExtraImageUrl3',
        'extra_image_url4': 'ExtraImageUrl4',
        'extra_image_url5': 'ExtraImageUrl5',
        'extra_image_url6': 'ExtraImageUrl6',
        'extra_image_url7': 'ExtraImageUrl7',
        'extra_image_url8': 'ExtraImageUrl8',
        'extra_image_url9': 'ExtraImageUrl9',
        'category_trail': 'CategoryTrail'
    }

    def __init__(self, id=None, parent_channel_product_no=None, grandparent_channel_product_no=None, mapped_fields=None, extra_data=None, name=None, description=None, brand=None, size=None, color=None, ean=None, manufacturer_product_number=None, merchant_product_no=None, stock=None, price=None, msrp=None, purchase_price=None, vat_rate_type=None, shipping_cost=None, shipping_time=None, url=None, image_url=None, extra_image_url1=None, extra_image_url2=None, extra_image_url3=None, extra_image_url4=None, extra_image_url5=None, extra_image_url6=None, extra_image_url7=None, extra_image_url8=None, extra_image_url9=None, category_trail=None, local_vars_configuration=None):  # noqa: E501
        """ChannelProductResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._parent_channel_product_no = None
        self._grandparent_channel_product_no = None
        self._mapped_fields = None
        self._extra_data = None
        self._name = None
        self._description = None
        self._brand = None
        self._size = None
        self._color = None
        self._ean = None
        self._manufacturer_product_number = None
        self._merchant_product_no = None
        self._stock = None
        self._price = None
        self._msrp = None
        self._purchase_price = None
        self._vat_rate_type = None
        self._shipping_cost = None
        self._shipping_time = None
        self._url = None
        self._image_url = None
        self._extra_image_url1 = None
        self._extra_image_url2 = None
        self._extra_image_url3 = None
        self._extra_image_url4 = None
        self._extra_image_url5 = None
        self._extra_image_url6 = None
        self._extra_image_url7 = None
        self._extra_image_url8 = None
        self._extra_image_url9 = None
        self._category_trail = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.parent_channel_product_no = parent_channel_product_no
        self.grandparent_channel_product_no = grandparent_channel_product_no
        self.mapped_fields = mapped_fields
        self.extra_data = extra_data
        self.name = name
        self.description = description
        self.brand = brand
        self.size = size
        self.color = color
        self.ean = ean
        self.manufacturer_product_number = manufacturer_product_number
        self.merchant_product_no = merchant_product_no
        if stock is not None:
            self.stock = stock
        if price is not None:
            self.price = price
        self.msrp = msrp
        self.purchase_price = purchase_price
        if vat_rate_type is not None:
            self.vat_rate_type = vat_rate_type
        self.shipping_cost = shipping_cost
        self.shipping_time = shipping_time
        self.url = url
        self.image_url = image_url
        self.extra_image_url1 = extra_image_url1
        self.extra_image_url2 = extra_image_url2
        self.extra_image_url3 = extra_image_url3
        self.extra_image_url4 = extra_image_url4
        self.extra_image_url5 = extra_image_url5
        self.extra_image_url6 = extra_image_url6
        self.extra_image_url7 = extra_image_url7
        self.extra_image_url8 = extra_image_url8
        self.extra_image_url9 = extra_image_url9
        self.category_trail = category_trail

    @property
    def id(self):
        """Gets the id of this ChannelProductResponse.  # noqa: E501

        An unique identifier which ChannelEngine uses to identify the product.  Needed in the call 'POST /v2/products/data'.  # noqa: E501

        :return: The id of this ChannelProductResponse.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ChannelProductResponse.

        An unique identifier which ChannelEngine uses to identify the product.  Needed in the call 'POST /v2/products/data'.  # noqa: E501

        :param id: The id of this ChannelProductResponse.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def parent_channel_product_no(self):
        """Gets the parent_channel_product_no of this ChannelProductResponse.  # noqa: E501

        The unique product reference used by the Channel for the parent product.  # noqa: E501

        :return: The parent_channel_product_no of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._parent_channel_product_no

    @parent_channel_product_no.setter
    def parent_channel_product_no(self, parent_channel_product_no):
        """Sets the parent_channel_product_no of this ChannelProductResponse.

        The unique product reference used by the Channel for the parent product.  # noqa: E501

        :param parent_channel_product_no: The parent_channel_product_no of this ChannelProductResponse.  # noqa: E501
        :type parent_channel_product_no: str
        """

        self._parent_channel_product_no = parent_channel_product_no

    @property
    def grandparent_channel_product_no(self):
        """Gets the grandparent_channel_product_no of this ChannelProductResponse.  # noqa: E501

        The unique product reference used by the Channel for the grandparent product.  # noqa: E501

        :return: The grandparent_channel_product_no of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._grandparent_channel_product_no

    @grandparent_channel_product_no.setter
    def grandparent_channel_product_no(self, grandparent_channel_product_no):
        """Sets the grandparent_channel_product_no of this ChannelProductResponse.

        The unique product reference used by the Channel for the grandparent product.  # noqa: E501

        :param grandparent_channel_product_no: The grandparent_channel_product_no of this ChannelProductResponse.  # noqa: E501
        :type grandparent_channel_product_no: str
        """

        self._grandparent_channel_product_no = grandparent_channel_product_no

    @property
    def mapped_fields(self):
        """Gets the mapped_fields of this ChannelProductResponse.  # noqa: E501

        A channel can require certain fields to be available. The channel  can provide ChannelEngine with this fields after which the merchants  will be able to fill in this field using custom conditions in ChannelEngine.  # noqa: E501

        :return: The mapped_fields of this ChannelProductResponse.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._mapped_fields

    @mapped_fields.setter
    def mapped_fields(self, mapped_fields):
        """Sets the mapped_fields of this ChannelProductResponse.

        A channel can require certain fields to be available. The channel  can provide ChannelEngine with this fields after which the merchants  will be able to fill in this field using custom conditions in ChannelEngine.  # noqa: E501

        :param mapped_fields: The mapped_fields of this ChannelProductResponse.  # noqa: E501
        :type mapped_fields: dict(str, str)
        """

        self._mapped_fields = mapped_fields

    @property
    def extra_data(self):
        """Gets the extra_data of this ChannelProductResponse.  # noqa: E501

        An optional list of key-value pairs containing  extra data about this product. This data can be  sent to channels or used for filtering products.  # noqa: E501

        :return: The extra_data of this ChannelProductResponse.  # noqa: E501
        :rtype: list[ChannelProductExtraDataItemResponse]
        """
        return self._extra_data

    @extra_data.setter
    def extra_data(self, extra_data):
        """Sets the extra_data of this ChannelProductResponse.

        An optional list of key-value pairs containing  extra data about this product. This data can be  sent to channels or used for filtering products.  # noqa: E501

        :param extra_data: The extra_data of this ChannelProductResponse.  # noqa: E501
        :type extra_data: list[ChannelProductExtraDataItemResponse]
        """

        self._extra_data = extra_data

    @property
    def name(self):
        """Gets the name of this ChannelProductResponse.  # noqa: E501

        The name of the product.  # noqa: E501

        :return: The name of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ChannelProductResponse.

        The name of the product.  # noqa: E501

        :param name: The name of this ChannelProductResponse.  # noqa: E501
        :type name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 256):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 0):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `0`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this ChannelProductResponse.  # noqa: E501

        A description of the product. Can contain these HTML tags:  div, span, pre, p, br, hr, hgroup, h1, h2, h3, h4, h5, h6, ul, ol, li, dl, dt, dd, strong, em, b, i, u, img, a, abbr, address, blockquote, area, audio, video, caption, table, tbody, td, tfoot, th, thead, tr.  # noqa: E501

        :return: The description of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ChannelProductResponse.

        A description of the product. Can contain these HTML tags:  div, span, pre, p, br, hr, hgroup, h1, h2, h3, h4, h5, h6, ul, ol, li, dl, dt, dd, strong, em, b, i, u, img, a, abbr, address, blockquote, area, audio, video, caption, table, tbody, td, tfoot, th, thead, tr.  # noqa: E501

        :param description: The description of this ChannelProductResponse.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def brand(self):
        """Gets the brand of this ChannelProductResponse.  # noqa: E501

        The brand of the product.  # noqa: E501

        :return: The brand of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._brand

    @brand.setter
    def brand(self, brand):
        """Sets the brand of this ChannelProductResponse.

        The brand of the product.  # noqa: E501

        :param brand: The brand of this ChannelProductResponse.  # noqa: E501
        :type brand: str
        """
        if (self.local_vars_configuration.client_side_validation and
                brand is not None and len(brand) > 256):
            raise ValueError("Invalid value for `brand`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                brand is not None and len(brand) < 0):
            raise ValueError("Invalid value for `brand`, length must be greater than or equal to `0`")  # noqa: E501

        self._brand = brand

    @property
    def size(self):
        """Gets the size of this ChannelProductResponse.  # noqa: E501

        Optional. The size of the product (variant). E.g. fashion size (S-XL, 46-56, etc), width of the watch, etc..  # noqa: E501

        :return: The size of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ChannelProductResponse.

        Optional. The size of the product (variant). E.g. fashion size (S-XL, 46-56, etc), width of the watch, etc..  # noqa: E501

        :param size: The size of this ChannelProductResponse.  # noqa: E501
        :type size: str
        """
        if (self.local_vars_configuration.client_side_validation and
                size is not None and len(size) > 64):
            raise ValueError("Invalid value for `size`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                size is not None and len(size) < 0):
            raise ValueError("Invalid value for `size`, length must be greater than or equal to `0`")  # noqa: E501

        self._size = size

    @property
    def color(self):
        """Gets the color of this ChannelProductResponse.  # noqa: E501

        Optional. The color of the product (variant).  # noqa: E501

        :return: The color of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this ChannelProductResponse.

        Optional. The color of the product (variant).  # noqa: E501

        :param color: The color of this ChannelProductResponse.  # noqa: E501
        :type color: str
        """
        if (self.local_vars_configuration.client_side_validation and
                color is not None and len(color) > 64):
            raise ValueError("Invalid value for `color`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                color is not None and len(color) < 0):
            raise ValueError("Invalid value for `color`, length must be greater than or equal to `0`")  # noqa: E501

        self._color = color

    @property
    def ean(self):
        """Gets the ean of this ChannelProductResponse.  # noqa: E501

        The EAN of GTIN of the product.  # noqa: E501

        :return: The ean of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._ean

    @ean.setter
    def ean(self, ean):
        """Sets the ean of this ChannelProductResponse.

        The EAN of GTIN of the product.  # noqa: E501

        :param ean: The ean of this ChannelProductResponse.  # noqa: E501
        :type ean: str
        """
        if (self.local_vars_configuration.client_side_validation and
                ean is not None and len(ean) > 64):
            raise ValueError("Invalid value for `ean`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                ean is not None and len(ean) < 0):
            raise ValueError("Invalid value for `ean`, length must be greater than or equal to `0`")  # noqa: E501

        self._ean = ean

    @property
    def manufacturer_product_number(self):
        """Gets the manufacturer_product_number of this ChannelProductResponse.  # noqa: E501

        The unique product reference used by the manufacturer/vendor of the product.  # noqa: E501

        :return: The manufacturer_product_number of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._manufacturer_product_number

    @manufacturer_product_number.setter
    def manufacturer_product_number(self, manufacturer_product_number):
        """Sets the manufacturer_product_number of this ChannelProductResponse.

        The unique product reference used by the manufacturer/vendor of the product.  # noqa: E501

        :param manufacturer_product_number: The manufacturer_product_number of this ChannelProductResponse.  # noqa: E501
        :type manufacturer_product_number: str
        """
        if (self.local_vars_configuration.client_side_validation and
                manufacturer_product_number is not None and len(manufacturer_product_number) > 64):
            raise ValueError("Invalid value for `manufacturer_product_number`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                manufacturer_product_number is not None and len(manufacturer_product_number) < 0):
            raise ValueError("Invalid value for `manufacturer_product_number`, length must be greater than or equal to `0`")  # noqa: E501

        self._manufacturer_product_number = manufacturer_product_number

    @property
    def merchant_product_no(self):
        """Gets the merchant_product_no of this ChannelProductResponse.  # noqa: E501

        A unique identifier of the product. (sku).  # noqa: E501

        :return: The merchant_product_no of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._merchant_product_no

    @merchant_product_no.setter
    def merchant_product_no(self, merchant_product_no):
        """Sets the merchant_product_no of this ChannelProductResponse.

        A unique identifier of the product. (sku).  # noqa: E501

        :param merchant_product_no: The merchant_product_no of this ChannelProductResponse.  # noqa: E501
        :type merchant_product_no: str
        """
        if self.local_vars_configuration.client_side_validation and merchant_product_no is None:  # noqa: E501
            raise ValueError("Invalid value for `merchant_product_no`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                merchant_product_no is not None and len(merchant_product_no) > 64):
            raise ValueError("Invalid value for `merchant_product_no`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                merchant_product_no is not None and len(merchant_product_no) < 0):
            raise ValueError("Invalid value for `merchant_product_no`, length must be greater than or equal to `0`")  # noqa: E501

        self._merchant_product_no = merchant_product_no

    @property
    def stock(self):
        """Gets the stock of this ChannelProductResponse.  # noqa: E501

        The number of items in stock.  # noqa: E501

        :return: The stock of this ChannelProductResponse.  # noqa: E501
        :rtype: int
        """
        return self._stock

    @stock.setter
    def stock(self, stock):
        """Sets the stock of this ChannelProductResponse.

        The number of items in stock.  # noqa: E501

        :param stock: The stock of this ChannelProductResponse.  # noqa: E501
        :type stock: int
        """
        if (self.local_vars_configuration.client_side_validation and
                stock is not None and stock < 0):  # noqa: E501
            raise ValueError("Invalid value for `stock`, must be a value greater than or equal to `0`")  # noqa: E501

        self._stock = stock

    @property
    def price(self):
        """Gets the price of this ChannelProductResponse.  # noqa: E501

        Price, including VAT.  # noqa: E501

        :return: The price of this ChannelProductResponse.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this ChannelProductResponse.

        Price, including VAT.  # noqa: E501

        :param price: The price of this ChannelProductResponse.  # noqa: E501
        :type price: float
        """
        if (self.local_vars_configuration.client_side_validation and
                price is not None and price < 0):  # noqa: E501
            raise ValueError("Invalid value for `price`, must be a value greater than or equal to `0`")  # noqa: E501

        self._price = price

    @property
    def msrp(self):
        """Gets the msrp of this ChannelProductResponse.  # noqa: E501

        Manufacturer's suggested retail price.  # noqa: E501

        :return: The msrp of this ChannelProductResponse.  # noqa: E501
        :rtype: float
        """
        return self._msrp

    @msrp.setter
    def msrp(self, msrp):
        """Sets the msrp of this ChannelProductResponse.

        Manufacturer's suggested retail price.  # noqa: E501

        :param msrp: The msrp of this ChannelProductResponse.  # noqa: E501
        :type msrp: float
        """

        self._msrp = msrp

    @property
    def purchase_price(self):
        """Gets the purchase_price of this ChannelProductResponse.  # noqa: E501

        Optional. The purchase price of the product. Useful for repricing.  # noqa: E501

        :return: The purchase_price of this ChannelProductResponse.  # noqa: E501
        :rtype: float
        """
        return self._purchase_price

    @purchase_price.setter
    def purchase_price(self, purchase_price):
        """Sets the purchase_price of this ChannelProductResponse.

        Optional. The purchase price of the product. Useful for repricing.  # noqa: E501

        :param purchase_price: The purchase_price of this ChannelProductResponse.  # noqa: E501
        :type purchase_price: float
        """

        self._purchase_price = purchase_price

    @property
    def vat_rate_type(self):
        """Gets the vat_rate_type of this ChannelProductResponse.  # noqa: E501

        The type of VAT which applies to this product.  See: http://ec.europa.eu/taxation_customs/taxation/vat/topics/rates_en.htm.  # noqa: E501

        :return: The vat_rate_type of this ChannelProductResponse.  # noqa: E501
        :rtype: VatRateType
        """
        return self._vat_rate_type

    @vat_rate_type.setter
    def vat_rate_type(self, vat_rate_type):
        """Sets the vat_rate_type of this ChannelProductResponse.

        The type of VAT which applies to this product.  See: http://ec.europa.eu/taxation_customs/taxation/vat/topics/rates_en.htm.  # noqa: E501

        :param vat_rate_type: The vat_rate_type of this ChannelProductResponse.  # noqa: E501
        :type vat_rate_type: VatRateType
        """

        self._vat_rate_type = vat_rate_type

    @property
    def shipping_cost(self):
        """Gets the shipping_cost of this ChannelProductResponse.  # noqa: E501

        Shipping cost of the product.  # noqa: E501

        :return: The shipping_cost of this ChannelProductResponse.  # noqa: E501
        :rtype: float
        """
        return self._shipping_cost

    @shipping_cost.setter
    def shipping_cost(self, shipping_cost):
        """Sets the shipping_cost of this ChannelProductResponse.

        Shipping cost of the product.  # noqa: E501

        :param shipping_cost: The shipping_cost of this ChannelProductResponse.  # noqa: E501
        :type shipping_cost: float
        """

        self._shipping_cost = shipping_cost

    @property
    def shipping_time(self):
        """Gets the shipping_time of this ChannelProductResponse.  # noqa: E501

        A textual representation of the shippingtime.  For example, in Dutch: 'Op werkdagen voor 22:00 uur besteld, morgen in huis'.  # noqa: E501

        :return: The shipping_time of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._shipping_time

    @shipping_time.setter
    def shipping_time(self, shipping_time):
        """Sets the shipping_time of this ChannelProductResponse.

        A textual representation of the shippingtime.  For example, in Dutch: 'Op werkdagen voor 22:00 uur besteld, morgen in huis'.  # noqa: E501

        :param shipping_time: The shipping_time of this ChannelProductResponse.  # noqa: E501
        :type shipping_time: str
        """
        if (self.local_vars_configuration.client_side_validation and
                shipping_time is not None and len(shipping_time) > 128):
            raise ValueError("Invalid value for `shipping_time`, length must be less than or equal to `128`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                shipping_time is not None and len(shipping_time) < 0):
            raise ValueError("Invalid value for `shipping_time`, length must be greater than or equal to `0`")  # noqa: E501

        self._shipping_time = shipping_time

    @property
    def url(self):
        """Gets the url of this ChannelProductResponse.  # noqa: E501

        A URL pointing to the merchant's webpage  which displays this product.  # noqa: E501

        :return: The url of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this ChannelProductResponse.

        A URL pointing to the merchant's webpage  which displays this product.  # noqa: E501

        :param url: The url of this ChannelProductResponse.  # noqa: E501
        :type url: str
        """
        if (self.local_vars_configuration.client_side_validation and
                url is not None and len(url) > 512):
            raise ValueError("Invalid value for `url`, length must be less than or equal to `512`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                url is not None and len(url) < 0):
            raise ValueError("Invalid value for `url`, length must be greater than or equal to `0`")  # noqa: E501

        self._url = url

    @property
    def image_url(self):
        """Gets the image_url of this ChannelProductResponse.  # noqa: E501

        A URL at which an image of this product  can be found.  # noqa: E501

        :return: The image_url of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._image_url

    @image_url.setter
    def image_url(self, image_url):
        """Sets the image_url of this ChannelProductResponse.

        A URL at which an image of this product  can be found.  # noqa: E501

        :param image_url: The image_url of this ChannelProductResponse.  # noqa: E501
        :type image_url: str
        """
        if (self.local_vars_configuration.client_side_validation and
                image_url is not None and len(image_url) > 512):
            raise ValueError("Invalid value for `image_url`, length must be less than or equal to `512`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                image_url is not None and len(image_url) < 0):
            raise ValueError("Invalid value for `image_url`, length must be greater than or equal to `0`")  # noqa: E501

        self._image_url = image_url

    @property
    def extra_image_url1(self):
        """Gets the extra_image_url1 of this ChannelProductResponse.  # noqa: E501

        Url to an additional image of product (1).  # noqa: E501

        :return: The extra_image_url1 of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._extra_image_url1

    @extra_image_url1.setter
    def extra_image_url1(self, extra_image_url1):
        """Sets the extra_image_url1 of this ChannelProductResponse.

        Url to an additional image of product (1).  # noqa: E501

        :param extra_image_url1: The extra_image_url1 of this ChannelProductResponse.  # noqa: E501
        :type extra_image_url1: str
        """
        if (self.local_vars_configuration.client_side_validation and
                extra_image_url1 is not None and len(extra_image_url1) > 512):
            raise ValueError("Invalid value for `extra_image_url1`, length must be less than or equal to `512`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                extra_image_url1 is not None and len(extra_image_url1) < 0):
            raise ValueError("Invalid value for `extra_image_url1`, length must be greater than or equal to `0`")  # noqa: E501

        self._extra_image_url1 = extra_image_url1

    @property
    def extra_image_url2(self):
        """Gets the extra_image_url2 of this ChannelProductResponse.  # noqa: E501

        Url to an additional image of product (2).  # noqa: E501

        :return: The extra_image_url2 of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._extra_image_url2

    @extra_image_url2.setter
    def extra_image_url2(self, extra_image_url2):
        """Sets the extra_image_url2 of this ChannelProductResponse.

        Url to an additional image of product (2).  # noqa: E501

        :param extra_image_url2: The extra_image_url2 of this ChannelProductResponse.  # noqa: E501
        :type extra_image_url2: str
        """
        if (self.local_vars_configuration.client_side_validation and
                extra_image_url2 is not None and len(extra_image_url2) > 512):
            raise ValueError("Invalid value for `extra_image_url2`, length must be less than or equal to `512`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                extra_image_url2 is not None and len(extra_image_url2) < 0):
            raise ValueError("Invalid value for `extra_image_url2`, length must be greater than or equal to `0`")  # noqa: E501

        self._extra_image_url2 = extra_image_url2

    @property
    def extra_image_url3(self):
        """Gets the extra_image_url3 of this ChannelProductResponse.  # noqa: E501

        Url to an additional image of product (3).  # noqa: E501

        :return: The extra_image_url3 of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._extra_image_url3

    @extra_image_url3.setter
    def extra_image_url3(self, extra_image_url3):
        """Sets the extra_image_url3 of this ChannelProductResponse.

        Url to an additional image of product (3).  # noqa: E501

        :param extra_image_url3: The extra_image_url3 of this ChannelProductResponse.  # noqa: E501
        :type extra_image_url3: str
        """
        if (self.local_vars_configuration.client_side_validation and
                extra_image_url3 is not None and len(extra_image_url3) > 512):
            raise ValueError("Invalid value for `extra_image_url3`, length must be less than or equal to `512`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                extra_image_url3 is not None and len(extra_image_url3) < 0):
            raise ValueError("Invalid value for `extra_image_url3`, length must be greater than or equal to `0`")  # noqa: E501

        self._extra_image_url3 = extra_image_url3

    @property
    def extra_image_url4(self):
        """Gets the extra_image_url4 of this ChannelProductResponse.  # noqa: E501

        Url to an additional image of product (4).  # noqa: E501

        :return: The extra_image_url4 of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._extra_image_url4

    @extra_image_url4.setter
    def extra_image_url4(self, extra_image_url4):
        """Sets the extra_image_url4 of this ChannelProductResponse.

        Url to an additional image of product (4).  # noqa: E501

        :param extra_image_url4: The extra_image_url4 of this ChannelProductResponse.  # noqa: E501
        :type extra_image_url4: str
        """
        if (self.local_vars_configuration.client_side_validation and
                extra_image_url4 is not None and len(extra_image_url4) > 512):
            raise ValueError("Invalid value for `extra_image_url4`, length must be less than or equal to `512`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                extra_image_url4 is not None and len(extra_image_url4) < 0):
            raise ValueError("Invalid value for `extra_image_url4`, length must be greater than or equal to `0`")  # noqa: E501

        self._extra_image_url4 = extra_image_url4

    @property
    def extra_image_url5(self):
        """Gets the extra_image_url5 of this ChannelProductResponse.  # noqa: E501

        Url to an additional image of product (5).  # noqa: E501

        :return: The extra_image_url5 of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._extra_image_url5

    @extra_image_url5.setter
    def extra_image_url5(self, extra_image_url5):
        """Sets the extra_image_url5 of this ChannelProductResponse.

        Url to an additional image of product (5).  # noqa: E501

        :param extra_image_url5: The extra_image_url5 of this ChannelProductResponse.  # noqa: E501
        :type extra_image_url5: str
        """
        if (self.local_vars_configuration.client_side_validation and
                extra_image_url5 is not None and len(extra_image_url5) > 512):
            raise ValueError("Invalid value for `extra_image_url5`, length must be less than or equal to `512`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                extra_image_url5 is not None and len(extra_image_url5) < 0):
            raise ValueError("Invalid value for `extra_image_url5`, length must be greater than or equal to `0`")  # noqa: E501

        self._extra_image_url5 = extra_image_url5

    @property
    def extra_image_url6(self):
        """Gets the extra_image_url6 of this ChannelProductResponse.  # noqa: E501

        Url to an additional image of product (6).  # noqa: E501

        :return: The extra_image_url6 of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._extra_image_url6

    @extra_image_url6.setter
    def extra_image_url6(self, extra_image_url6):
        """Sets the extra_image_url6 of this ChannelProductResponse.

        Url to an additional image of product (6).  # noqa: E501

        :param extra_image_url6: The extra_image_url6 of this ChannelProductResponse.  # noqa: E501
        :type extra_image_url6: str
        """
        if (self.local_vars_configuration.client_side_validation and
                extra_image_url6 is not None and len(extra_image_url6) > 512):
            raise ValueError("Invalid value for `extra_image_url6`, length must be less than or equal to `512`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                extra_image_url6 is not None and len(extra_image_url6) < 0):
            raise ValueError("Invalid value for `extra_image_url6`, length must be greater than or equal to `0`")  # noqa: E501

        self._extra_image_url6 = extra_image_url6

    @property
    def extra_image_url7(self):
        """Gets the extra_image_url7 of this ChannelProductResponse.  # noqa: E501

        Url to an additional image of product (7).  # noqa: E501

        :return: The extra_image_url7 of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._extra_image_url7

    @extra_image_url7.setter
    def extra_image_url7(self, extra_image_url7):
        """Sets the extra_image_url7 of this ChannelProductResponse.

        Url to an additional image of product (7).  # noqa: E501

        :param extra_image_url7: The extra_image_url7 of this ChannelProductResponse.  # noqa: E501
        :type extra_image_url7: str
        """
        if (self.local_vars_configuration.client_side_validation and
                extra_image_url7 is not None and len(extra_image_url7) > 512):
            raise ValueError("Invalid value for `extra_image_url7`, length must be less than or equal to `512`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                extra_image_url7 is not None and len(extra_image_url7) < 0):
            raise ValueError("Invalid value for `extra_image_url7`, length must be greater than or equal to `0`")  # noqa: E501

        self._extra_image_url7 = extra_image_url7

    @property
    def extra_image_url8(self):
        """Gets the extra_image_url8 of this ChannelProductResponse.  # noqa: E501

        Url to an additional image of product (8).  # noqa: E501

        :return: The extra_image_url8 of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._extra_image_url8

    @extra_image_url8.setter
    def extra_image_url8(self, extra_image_url8):
        """Sets the extra_image_url8 of this ChannelProductResponse.

        Url to an additional image of product (8).  # noqa: E501

        :param extra_image_url8: The extra_image_url8 of this ChannelProductResponse.  # noqa: E501
        :type extra_image_url8: str
        """
        if (self.local_vars_configuration.client_side_validation and
                extra_image_url8 is not None and len(extra_image_url8) > 512):
            raise ValueError("Invalid value for `extra_image_url8`, length must be less than or equal to `512`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                extra_image_url8 is not None and len(extra_image_url8) < 0):
            raise ValueError("Invalid value for `extra_image_url8`, length must be greater than or equal to `0`")  # noqa: E501

        self._extra_image_url8 = extra_image_url8

    @property
    def extra_image_url9(self):
        """Gets the extra_image_url9 of this ChannelProductResponse.  # noqa: E501

        Url to an additional image of product (9).  # noqa: E501

        :return: The extra_image_url9 of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._extra_image_url9

    @extra_image_url9.setter
    def extra_image_url9(self, extra_image_url9):
        """Sets the extra_image_url9 of this ChannelProductResponse.

        Url to an additional image of product (9).  # noqa: E501

        :param extra_image_url9: The extra_image_url9 of this ChannelProductResponse.  # noqa: E501
        :type extra_image_url9: str
        """
        if (self.local_vars_configuration.client_side_validation and
                extra_image_url9 is not None and len(extra_image_url9) > 512):
            raise ValueError("Invalid value for `extra_image_url9`, length must be less than or equal to `512`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                extra_image_url9 is not None and len(extra_image_url9) < 0):
            raise ValueError("Invalid value for `extra_image_url9`, length must be greater than or equal to `0`")  # noqa: E501

        self._extra_image_url9 = extra_image_url9

    @property
    def category_trail(self):
        """Gets the category_trail of this ChannelProductResponse.  # noqa: E501

        The category to which this product belongs.  Please supply this field in the following format:  'maincategory > category > subcategory'  For example:  'vehicles > bikes > mountainbike'.  # noqa: E501

        :return: The category_trail of this ChannelProductResponse.  # noqa: E501
        :rtype: str
        """
        return self._category_trail

    @category_trail.setter
    def category_trail(self, category_trail):
        """Sets the category_trail of this ChannelProductResponse.

        The category to which this product belongs.  Please supply this field in the following format:  'maincategory > category > subcategory'  For example:  'vehicles > bikes > mountainbike'.  # noqa: E501

        :param category_trail: The category_trail of this ChannelProductResponse.  # noqa: E501
        :type category_trail: str
        """

        self._category_trail = category_trail

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChannelProductResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChannelProductResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.9.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from channelengine_channel_api_client.configuration import Configuration


class ChannelOrderLineResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'status': 'OrderStatusView',
        'is_fulfillment_by_marketplace': 'bool',
        'gtin': 'str',
        'description': 'str',
        'unit_vat': 'float',
        'line_total_incl_vat': 'float',
        'line_vat': 'float',
        'original_unit_price_incl_vat': 'float',
        'original_unit_vat': 'float',
        'original_line_total_incl_vat': 'float',
        'original_line_vat': 'float',
        'original_fee_fixed': 'float',
        'bundle_product_merchant_product_no': 'str',
        'channel_product_no': 'str',
        'merchant_product_no': 'str',
        'quantity': 'int',
        'cancellation_requested_quantity': 'int',
        'unit_price_incl_vat': 'float',
        'fee_fixed': 'float',
        'fee_rate': 'float',
        'condition': 'Condition',
        'expected_delivery_date': 'datetime'
    }

    attribute_map = {
        'status': 'Status',
        'is_fulfillment_by_marketplace': 'IsFulfillmentByMarketplace',
        'gtin': 'Gtin',
        'description': 'Description',
        'unit_vat': 'UnitVat',
        'line_total_incl_vat': 'LineTotalInclVat',
        'line_vat': 'LineVat',
        'original_unit_price_incl_vat': 'OriginalUnitPriceInclVat',
        'original_unit_vat': 'OriginalUnitVat',
        'original_line_total_incl_vat': 'OriginalLineTotalInclVat',
        'original_line_vat': 'OriginalLineVat',
        'original_fee_fixed': 'OriginalFeeFixed',
        'bundle_product_merchant_product_no': 'BundleProductMerchantProductNo',
        'channel_product_no': 'ChannelProductNo',
        'merchant_product_no': 'MerchantProductNo',
        'quantity': 'Quantity',
        'cancellation_requested_quantity': 'CancellationRequestedQuantity',
        'unit_price_incl_vat': 'UnitPriceInclVat',
        'fee_fixed': 'FeeFixed',
        'fee_rate': 'FeeRate',
        'condition': 'Condition',
        'expected_delivery_date': 'ExpectedDeliveryDate'
    }

    def __init__(self, status=None, is_fulfillment_by_marketplace=None, gtin=None, description=None, unit_vat=None, line_total_incl_vat=None, line_vat=None, original_unit_price_incl_vat=None, original_unit_vat=None, original_line_total_incl_vat=None, original_line_vat=None, original_fee_fixed=None, bundle_product_merchant_product_no=None, channel_product_no=None, merchant_product_no=None, quantity=None, cancellation_requested_quantity=None, unit_price_incl_vat=None, fee_fixed=None, fee_rate=None, condition=None, expected_delivery_date=None, local_vars_configuration=None):  # noqa: E501
        """ChannelOrderLineResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._status = None
        self._is_fulfillment_by_marketplace = None
        self._gtin = None
        self._description = None
        self._unit_vat = None
        self._line_total_incl_vat = None
        self._line_vat = None
        self._original_unit_price_incl_vat = None
        self._original_unit_vat = None
        self._original_line_total_incl_vat = None
        self._original_line_vat = None
        self._original_fee_fixed = None
        self._bundle_product_merchant_product_no = None
        self._channel_product_no = None
        self._merchant_product_no = None
        self._quantity = None
        self._cancellation_requested_quantity = None
        self._unit_price_incl_vat = None
        self._fee_fixed = None
        self._fee_rate = None
        self._condition = None
        self._expected_delivery_date = None
        self.discriminator = None

        if status is not None:
            self.status = status
        if is_fulfillment_by_marketplace is not None:
            self.is_fulfillment_by_marketplace = is_fulfillment_by_marketplace
        self.gtin = gtin
        self.description = description
        self.unit_vat = unit_vat
        self.line_total_incl_vat = line_total_incl_vat
        self.line_vat = line_vat
        self.original_unit_price_incl_vat = original_unit_price_incl_vat
        self.original_unit_vat = original_unit_vat
        self.original_line_total_incl_vat = original_line_total_incl_vat
        self.original_line_vat = original_line_vat
        if original_fee_fixed is not None:
            self.original_fee_fixed = original_fee_fixed
        self.bundle_product_merchant_product_no = bundle_product_merchant_product_no
        self.channel_product_no = channel_product_no
        self.merchant_product_no = merchant_product_no
        self.quantity = quantity
        if cancellation_requested_quantity is not None:
            self.cancellation_requested_quantity = cancellation_requested_quantity
        self.unit_price_incl_vat = unit_price_incl_vat
        if fee_fixed is not None:
            self.fee_fixed = fee_fixed
        if fee_rate is not None:
            self.fee_rate = fee_rate
        if condition is not None:
            self.condition = condition
        self.expected_delivery_date = expected_delivery_date

    @property
    def status(self):
        """Gets the status of this ChannelOrderLineResponse.  # noqa: E501

        The status of the order.  # noqa: E501

        :return: The status of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: OrderStatusView
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ChannelOrderLineResponse.

        The status of the order.  # noqa: E501

        :param status: The status of this ChannelOrderLineResponse.  # noqa: E501
        :type status: OrderStatusView
        """

        self._status = status

    @property
    def is_fulfillment_by_marketplace(self):
        """Gets the is_fulfillment_by_marketplace of this ChannelOrderLineResponse.  # noqa: E501

        Is the order fulfilled by the marketplace (amazon: FBA, bol: LVB, etc.)?.  # noqa: E501

        :return: The is_fulfillment_by_marketplace of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_fulfillment_by_marketplace

    @is_fulfillment_by_marketplace.setter
    def is_fulfillment_by_marketplace(self, is_fulfillment_by_marketplace):
        """Sets the is_fulfillment_by_marketplace of this ChannelOrderLineResponse.

        Is the order fulfilled by the marketplace (amazon: FBA, bol: LVB, etc.)?.  # noqa: E501

        :param is_fulfillment_by_marketplace: The is_fulfillment_by_marketplace of this ChannelOrderLineResponse.  # noqa: E501
        :type is_fulfillment_by_marketplace: bool
        """

        self._is_fulfillment_by_marketplace = is_fulfillment_by_marketplace

    @property
    def gtin(self):
        """Gets the gtin of this ChannelOrderLineResponse.  # noqa: E501

        Either the GTIN (EAN, ISBN, UPC etc) provided by the channel, or the the GTIN belonging to the MerchantProductNo in ChannelEngine.  # noqa: E501

        :return: The gtin of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: str
        """
        return self._gtin

    @gtin.setter
    def gtin(self, gtin):
        """Sets the gtin of this ChannelOrderLineResponse.

        Either the GTIN (EAN, ISBN, UPC etc) provided by the channel, or the the GTIN belonging to the MerchantProductNo in ChannelEngine.  # noqa: E501

        :param gtin: The gtin of this ChannelOrderLineResponse.  # noqa: E501
        :type gtin: str
        """

        self._gtin = gtin

    @property
    def description(self):
        """Gets the description of this ChannelOrderLineResponse.  # noqa: E501

        The product description (or title) provided by the channel.  # noqa: E501

        :return: The description of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ChannelOrderLineResponse.

        The product description (or title) provided by the channel.  # noqa: E501

        :param description: The description of this ChannelOrderLineResponse.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def unit_vat(self):
        """Gets the unit_vat of this ChannelOrderLineResponse.  # noqa: E501

        The total amount of VAT charged over the value of a single unit of the ordered product  (in the shop's base currency calculated using the exchange rate at the time of ordering).  # noqa: E501

        :return: The unit_vat of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: float
        """
        return self._unit_vat

    @unit_vat.setter
    def unit_vat(self, unit_vat):
        """Sets the unit_vat of this ChannelOrderLineResponse.

        The total amount of VAT charged over the value of a single unit of the ordered product  (in the shop's base currency calculated using the exchange rate at the time of ordering).  # noqa: E501

        :param unit_vat: The unit_vat of this ChannelOrderLineResponse.  # noqa: E501
        :type unit_vat: float
        """

        self._unit_vat = unit_vat

    @property
    def line_total_incl_vat(self):
        """Gets the line_total_incl_vat of this ChannelOrderLineResponse.  # noqa: E501

        The total value of the order line (quantity * unit price) including VAT  (in the shop's base currency calculated using the exchange rate at the time of ordering).  # noqa: E501

        :return: The line_total_incl_vat of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: float
        """
        return self._line_total_incl_vat

    @line_total_incl_vat.setter
    def line_total_incl_vat(self, line_total_incl_vat):
        """Sets the line_total_incl_vat of this ChannelOrderLineResponse.

        The total value of the order line (quantity * unit price) including VAT  (in the shop's base currency calculated using the exchange rate at the time of ordering).  # noqa: E501

        :param line_total_incl_vat: The line_total_incl_vat of this ChannelOrderLineResponse.  # noqa: E501
        :type line_total_incl_vat: float
        """

        self._line_total_incl_vat = line_total_incl_vat

    @property
    def line_vat(self):
        """Gets the line_vat of this ChannelOrderLineResponse.  # noqa: E501

        The total amount of VAT charged over the total value of the order line (quantity * unit price)  (in the shop's base currency calculated using the exchange rate at the time of ordering).  # noqa: E501

        :return: The line_vat of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: float
        """
        return self._line_vat

    @line_vat.setter
    def line_vat(self, line_vat):
        """Sets the line_vat of this ChannelOrderLineResponse.

        The total amount of VAT charged over the total value of the order line (quantity * unit price)  (in the shop's base currency calculated using the exchange rate at the time of ordering).  # noqa: E501

        :param line_vat: The line_vat of this ChannelOrderLineResponse.  # noqa: E501
        :type line_vat: float
        """

        self._line_vat = line_vat

    @property
    def original_unit_price_incl_vat(self):
        """Gets the original_unit_price_incl_vat of this ChannelOrderLineResponse.  # noqa: E501

        The value of a single unit of the ordered product including VAT  (in the currency in which the order was paid for, see CurrencyCode).  # noqa: E501

        :return: The original_unit_price_incl_vat of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: float
        """
        return self._original_unit_price_incl_vat

    @original_unit_price_incl_vat.setter
    def original_unit_price_incl_vat(self, original_unit_price_incl_vat):
        """Sets the original_unit_price_incl_vat of this ChannelOrderLineResponse.

        The value of a single unit of the ordered product including VAT  (in the currency in which the order was paid for, see CurrencyCode).  # noqa: E501

        :param original_unit_price_incl_vat: The original_unit_price_incl_vat of this ChannelOrderLineResponse.  # noqa: E501
        :type original_unit_price_incl_vat: float
        """

        self._original_unit_price_incl_vat = original_unit_price_incl_vat

    @property
    def original_unit_vat(self):
        """Gets the original_unit_vat of this ChannelOrderLineResponse.  # noqa: E501

        The total amount of VAT charged over the value of a single unit of the ordered product  (in the currency in which the order was paid for, see CurrencyCode).  # noqa: E501

        :return: The original_unit_vat of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: float
        """
        return self._original_unit_vat

    @original_unit_vat.setter
    def original_unit_vat(self, original_unit_vat):
        """Sets the original_unit_vat of this ChannelOrderLineResponse.

        The total amount of VAT charged over the value of a single unit of the ordered product  (in the currency in which the order was paid for, see CurrencyCode).  # noqa: E501

        :param original_unit_vat: The original_unit_vat of this ChannelOrderLineResponse.  # noqa: E501
        :type original_unit_vat: float
        """

        self._original_unit_vat = original_unit_vat

    @property
    def original_line_total_incl_vat(self):
        """Gets the original_line_total_incl_vat of this ChannelOrderLineResponse.  # noqa: E501

        The total value of the order line (quantity * unit price) including VAT  (in the currency in which the order was paid for, see CurrencyCode).  # noqa: E501

        :return: The original_line_total_incl_vat of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: float
        """
        return self._original_line_total_incl_vat

    @original_line_total_incl_vat.setter
    def original_line_total_incl_vat(self, original_line_total_incl_vat):
        """Sets the original_line_total_incl_vat of this ChannelOrderLineResponse.

        The total value of the order line (quantity * unit price) including VAT  (in the currency in which the order was paid for, see CurrencyCode).  # noqa: E501

        :param original_line_total_incl_vat: The original_line_total_incl_vat of this ChannelOrderLineResponse.  # noqa: E501
        :type original_line_total_incl_vat: float
        """

        self._original_line_total_incl_vat = original_line_total_incl_vat

    @property
    def original_line_vat(self):
        """Gets the original_line_vat of this ChannelOrderLineResponse.  # noqa: E501

        The total amount of VAT charged over the total value of the order line (quantity * unit price)  (in the currency in which the order was paid for, see CurrencyCode).  # noqa: E501

        :return: The original_line_vat of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: float
        """
        return self._original_line_vat

    @original_line_vat.setter
    def original_line_vat(self, original_line_vat):
        """Sets the original_line_vat of this ChannelOrderLineResponse.

        The total amount of VAT charged over the total value of the order line (quantity * unit price)  (in the currency in which the order was paid for, see CurrencyCode).  # noqa: E501

        :param original_line_vat: The original_line_vat of this ChannelOrderLineResponse.  # noqa: E501
        :type original_line_vat: float
        """

        self._original_line_vat = original_line_vat

    @property
    def original_fee_fixed(self):
        """Gets the original_fee_fixed of this ChannelOrderLineResponse.  # noqa: E501

        A percentage fee that is charged by the Channel for this orderline.  This fee rate is based on the currency of client  This field is optional, send 0 if not applicable.  # noqa: E501

        :return: The original_fee_fixed of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: float
        """
        return self._original_fee_fixed

    @original_fee_fixed.setter
    def original_fee_fixed(self, original_fee_fixed):
        """Sets the original_fee_fixed of this ChannelOrderLineResponse.

        A percentage fee that is charged by the Channel for this orderline.  This fee rate is based on the currency of client  This field is optional, send 0 if not applicable.  # noqa: E501

        :param original_fee_fixed: The original_fee_fixed of this ChannelOrderLineResponse.  # noqa: E501
        :type original_fee_fixed: float
        """

        self._original_fee_fixed = original_fee_fixed

    @property
    def bundle_product_merchant_product_no(self):
        """Gets the bundle_product_merchant_product_no of this ChannelOrderLineResponse.  # noqa: E501

        If the product is ordered part of a bundle, this field contains the MerchantProductNo of  the product bundle.  # noqa: E501

        :return: The bundle_product_merchant_product_no of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: str
        """
        return self._bundle_product_merchant_product_no

    @bundle_product_merchant_product_no.setter
    def bundle_product_merchant_product_no(self, bundle_product_merchant_product_no):
        """Sets the bundle_product_merchant_product_no of this ChannelOrderLineResponse.

        If the product is ordered part of a bundle, this field contains the MerchantProductNo of  the product bundle.  # noqa: E501

        :param bundle_product_merchant_product_no: The bundle_product_merchant_product_no of this ChannelOrderLineResponse.  # noqa: E501
        :type bundle_product_merchant_product_no: str
        """

        self._bundle_product_merchant_product_no = bundle_product_merchant_product_no

    @property
    def channel_product_no(self):
        """Gets the channel_product_no of this ChannelOrderLineResponse.  # noqa: E501

        The unique product reference used by the channel.  # noqa: E501

        :return: The channel_product_no of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: str
        """
        return self._channel_product_no

    @channel_product_no.setter
    def channel_product_no(self, channel_product_no):
        """Sets the channel_product_no of this ChannelOrderLineResponse.

        The unique product reference used by the channel.  # noqa: E501

        :param channel_product_no: The channel_product_no of this ChannelOrderLineResponse.  # noqa: E501
        :type channel_product_no: str
        """
        if self.local_vars_configuration.client_side_validation and channel_product_no is None:  # noqa: E501
            raise ValueError("Invalid value for `channel_product_no`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                channel_product_no is not None and len(channel_product_no) > 60):
            raise ValueError("Invalid value for `channel_product_no`, length must be less than or equal to `60`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                channel_product_no is not None and len(channel_product_no) < 0):
            raise ValueError("Invalid value for `channel_product_no`, length must be greater than or equal to `0`")  # noqa: E501

        self._channel_product_no = channel_product_no

    @property
    def merchant_product_no(self):
        """Gets the merchant_product_no of this ChannelOrderLineResponse.  # noqa: E501

        The unique product reference used by the merchant.  # noqa: E501

        :return: The merchant_product_no of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: str
        """
        return self._merchant_product_no

    @merchant_product_no.setter
    def merchant_product_no(self, merchant_product_no):
        """Sets the merchant_product_no of this ChannelOrderLineResponse.

        The unique product reference used by the merchant.  # noqa: E501

        :param merchant_product_no: The merchant_product_no of this ChannelOrderLineResponse.  # noqa: E501
        :type merchant_product_no: str
        """
        if (self.local_vars_configuration.client_side_validation and
                merchant_product_no is not None and len(merchant_product_no) > 50):
            raise ValueError("Invalid value for `merchant_product_no`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                merchant_product_no is not None and len(merchant_product_no) < 0):
            raise ValueError("Invalid value for `merchant_product_no`, length must be greater than or equal to `0`")  # noqa: E501

        self._merchant_product_no = merchant_product_no

    @property
    def quantity(self):
        """Gets the quantity of this ChannelOrderLineResponse.  # noqa: E501

        The number of items of the product.  # noqa: E501

        :return: The quantity of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this ChannelOrderLineResponse.

        The number of items of the product.  # noqa: E501

        :param quantity: The quantity of this ChannelOrderLineResponse.  # noqa: E501
        :type quantity: int
        """
        if self.local_vars_configuration.client_side_validation and quantity is None:  # noqa: E501
            raise ValueError("Invalid value for `quantity`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                quantity is not None and quantity < 0):  # noqa: E501
            raise ValueError("Invalid value for `quantity`, must be a value greater than or equal to `0`")  # noqa: E501

        self._quantity = quantity

    @property
    def cancellation_requested_quantity(self):
        """Gets the cancellation_requested_quantity of this ChannelOrderLineResponse.  # noqa: E501

        The number of items for which cancellation was requested by the customer.  Some channels allow a customer to cancel an order until it has been shipped.  When an order has already been acknowledged in ChannelEngine, it can only be cancelled by creating a cancellation.  Use this field to check whether it is still possible to cancel the order. If this is the case, submit a cancellation to ChannelEngine.  # noqa: E501

        :return: The cancellation_requested_quantity of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: int
        """
        return self._cancellation_requested_quantity

    @cancellation_requested_quantity.setter
    def cancellation_requested_quantity(self, cancellation_requested_quantity):
        """Sets the cancellation_requested_quantity of this ChannelOrderLineResponse.

        The number of items for which cancellation was requested by the customer.  Some channels allow a customer to cancel an order until it has been shipped.  When an order has already been acknowledged in ChannelEngine, it can only be cancelled by creating a cancellation.  Use this field to check whether it is still possible to cancel the order. If this is the case, submit a cancellation to ChannelEngine.  # noqa: E501

        :param cancellation_requested_quantity: The cancellation_requested_quantity of this ChannelOrderLineResponse.  # noqa: E501
        :type cancellation_requested_quantity: int
        """
        if (self.local_vars_configuration.client_side_validation and
                cancellation_requested_quantity is not None and cancellation_requested_quantity < 0):  # noqa: E501
            raise ValueError("Invalid value for `cancellation_requested_quantity`, must be a value greater than or equal to `0`")  # noqa: E501

        self._cancellation_requested_quantity = cancellation_requested_quantity

    @property
    def unit_price_incl_vat(self):
        """Gets the unit_price_incl_vat of this ChannelOrderLineResponse.  # noqa: E501

        The value of a single unit of the ordered product including VAT  (in the shop's base currency calculated using the exchange rate at the time of ordering).  # noqa: E501

        :return: The unit_price_incl_vat of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: float
        """
        return self._unit_price_incl_vat

    @unit_price_incl_vat.setter
    def unit_price_incl_vat(self, unit_price_incl_vat):
        """Sets the unit_price_incl_vat of this ChannelOrderLineResponse.

        The value of a single unit of the ordered product including VAT  (in the shop's base currency calculated using the exchange rate at the time of ordering).  # noqa: E501

        :param unit_price_incl_vat: The unit_price_incl_vat of this ChannelOrderLineResponse.  # noqa: E501
        :type unit_price_incl_vat: float
        """
        if self.local_vars_configuration.client_side_validation and unit_price_incl_vat is None:  # noqa: E501
            raise ValueError("Invalid value for `unit_price_incl_vat`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                unit_price_incl_vat is not None and unit_price_incl_vat < 0):  # noqa: E501
            raise ValueError("Invalid value for `unit_price_incl_vat`, must be a value greater than or equal to `0`")  # noqa: E501

        self._unit_price_incl_vat = unit_price_incl_vat

    @property
    def fee_fixed(self):
        """Gets the fee_fixed of this ChannelOrderLineResponse.  # noqa: E501

        A fixed fee that is charged by the Channel for this orderline.  This fee rate is based on the currency of the Channel  This field is optional, send 0 if not applicable.  # noqa: E501

        :return: The fee_fixed of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: float
        """
        return self._fee_fixed

    @fee_fixed.setter
    def fee_fixed(self, fee_fixed):
        """Sets the fee_fixed of this ChannelOrderLineResponse.

        A fixed fee that is charged by the Channel for this orderline.  This fee rate is based on the currency of the Channel  This field is optional, send 0 if not applicable.  # noqa: E501

        :param fee_fixed: The fee_fixed of this ChannelOrderLineResponse.  # noqa: E501
        :type fee_fixed: float
        """
        if (self.local_vars_configuration.client_side_validation and
                fee_fixed is not None and fee_fixed < 0):  # noqa: E501
            raise ValueError("Invalid value for `fee_fixed`, must be a value greater than or equal to `0`")  # noqa: E501

        self._fee_fixed = fee_fixed

    @property
    def fee_rate(self):
        """Gets the fee_rate of this ChannelOrderLineResponse.  # noqa: E501

        A percentage fee that is charged by the Channel for this orderline.  This field is optional, send 0 if not applicable.  # noqa: E501

        :return: The fee_rate of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: float
        """
        return self._fee_rate

    @fee_rate.setter
    def fee_rate(self, fee_rate):
        """Sets the fee_rate of this ChannelOrderLineResponse.

        A percentage fee that is charged by the Channel for this orderline.  This field is optional, send 0 if not applicable.  # noqa: E501

        :param fee_rate: The fee_rate of this ChannelOrderLineResponse.  # noqa: E501
        :type fee_rate: float
        """
        if (self.local_vars_configuration.client_side_validation and
                fee_rate is not None and fee_rate < 0):  # noqa: E501
            raise ValueError("Invalid value for `fee_rate`, must be a value greater than or equal to `0`")  # noqa: E501

        self._fee_rate = fee_rate

    @property
    def condition(self):
        """Gets the condition of this ChannelOrderLineResponse.  # noqa: E501

        The condition of the product, this can be used to indicate that a product is a second-hand product.  # noqa: E501

        :return: The condition of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: Condition
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        """Sets the condition of this ChannelOrderLineResponse.

        The condition of the product, this can be used to indicate that a product is a second-hand product.  # noqa: E501

        :param condition: The condition of this ChannelOrderLineResponse.  # noqa: E501
        :type condition: Condition
        """

        self._condition = condition

    @property
    def expected_delivery_date(self):
        """Gets the expected_delivery_date of this ChannelOrderLineResponse.  # noqa: E501

        Expected delivery date from channels, empty if channels not support this value  # noqa: E501

        :return: The expected_delivery_date of this ChannelOrderLineResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._expected_delivery_date

    @expected_delivery_date.setter
    def expected_delivery_date(self, expected_delivery_date):
        """Sets the expected_delivery_date of this ChannelOrderLineResponse.

        Expected delivery date from channels, empty if channels not support this value  # noqa: E501

        :param expected_delivery_date: The expected_delivery_date of this ChannelOrderLineResponse.  # noqa: E501
        :type expected_delivery_date: datetime
        """

        self._expected_delivery_date = expected_delivery_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChannelOrderLineResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChannelOrderLineResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.9.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from channelengine_channel_api_client.configuration import Configuration


class ChannelOfferResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'channel_product_no': 'str',
        'merchant_product_no': 'str',
        'price': 'float',
        'stock': 'int',
        'mapped_fields': 'dict(str, str)'
    }

    attribute_map = {
        'channel_product_no': 'ChannelProductNo',
        'merchant_product_no': 'MerchantProductNo',
        'price': 'Price',
        'stock': 'Stock',
        'mapped_fields': 'MappedFields'
    }

    def __init__(self, channel_product_no=None, merchant_product_no=None, price=None, stock=None, mapped_fields=None, local_vars_configuration=None):  # noqa: E501
        """ChannelOfferResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._channel_product_no = None
        self._merchant_product_no = None
        self._price = None
        self._stock = None
        self._mapped_fields = None
        self.discriminator = None

        self.channel_product_no = channel_product_no
        self.merchant_product_no = merchant_product_no
        if price is not None:
            self.price = price
        if stock is not None:
            self.stock = stock
        self.mapped_fields = mapped_fields

    @property
    def channel_product_no(self):
        """Gets the channel_product_no of this ChannelOfferResponse.  # noqa: E501

        The unique product reference used by the Channel.  # noqa: E501

        :return: The channel_product_no of this ChannelOfferResponse.  # noqa: E501
        :rtype: str
        """
        return self._channel_product_no

    @channel_product_no.setter
    def channel_product_no(self, channel_product_no):
        """Sets the channel_product_no of this ChannelOfferResponse.

        The unique product reference used by the Channel.  # noqa: E501

        :param channel_product_no: The channel_product_no of this ChannelOfferResponse.  # noqa: E501
        :type channel_product_no: str
        """

        self._channel_product_no = channel_product_no

    @property
    def merchant_product_no(self):
        """Gets the merchant_product_no of this ChannelOfferResponse.  # noqa: E501


        :return: The merchant_product_no of this ChannelOfferResponse.  # noqa: E501
        :rtype: str
        """
        return self._merchant_product_no

    @merchant_product_no.setter
    def merchant_product_no(self, merchant_product_no):
        """Sets the merchant_product_no of this ChannelOfferResponse.


        :param merchant_product_no: The merchant_product_no of this ChannelOfferResponse.  # noqa: E501
        :type merchant_product_no: str
        """

        self._merchant_product_no = merchant_product_no

    @property
    def price(self):
        """Gets the price of this ChannelOfferResponse.  # noqa: E501


        :return: The price of this ChannelOfferResponse.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this ChannelOfferResponse.


        :param price: The price of this ChannelOfferResponse.  # noqa: E501
        :type price: float
        """

        self._price = price

    @property
    def stock(self):
        """Gets the stock of this ChannelOfferResponse.  # noqa: E501


        :return: The stock of this ChannelOfferResponse.  # noqa: E501
        :rtype: int
        """
        return self._stock

    @stock.setter
    def stock(self, stock):
        """Sets the stock of this ChannelOfferResponse.


        :param stock: The stock of this ChannelOfferResponse.  # noqa: E501
        :type stock: int
        """

        self._stock = stock

    @property
    def mapped_fields(self):
        """Gets the mapped_fields of this ChannelOfferResponse.  # noqa: E501

        A channel can require certain fields to be available. The channel  can provide ChannelEngine with this fields after which the merchants  will be able to fill in this field using custom conditions in ChannelEngine.  # noqa: E501

        :return: The mapped_fields of this ChannelOfferResponse.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._mapped_fields

    @mapped_fields.setter
    def mapped_fields(self, mapped_fields):
        """Sets the mapped_fields of this ChannelOfferResponse.

        A channel can require certain fields to be available. The channel  can provide ChannelEngine with this fields after which the merchants  will be able to fill in this field using custom conditions in ChannelEngine.  # noqa: E501

        :param mapped_fields: The mapped_fields of this ChannelOfferResponse.  # noqa: E501
        :type mapped_fields: dict(str, str)
        """

        self._mapped_fields = mapped_fields

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChannelOfferResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChannelOfferResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.9.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from channelengine_channel_api_client.configuration import Configuration


class ChannelReturnLineResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'channel_product_no': 'str',
        'merchant_product_no': 'str',
        'accepted_quantity': 'int',
        'rejected_quantity': 'int',
        'order_line': 'ChannelOrderLineResponse',
        'shipment_status': 'ShipmentLineStatus',
        'quantity': 'int'
    }

    attribute_map = {
        'channel_product_no': 'ChannelProductNo',
        'merchant_product_no': 'MerchantProductNo',
        'accepted_quantity': 'AcceptedQuantity',
        'rejected_quantity': 'RejectedQuantity',
        'order_line': 'OrderLine',
        'shipment_status': 'ShipmentStatus',
        'quantity': 'Quantity'
    }

    def __init__(self, channel_product_no=None, merchant_product_no=None, accepted_quantity=None, rejected_quantity=None, order_line=None, shipment_status=None, quantity=None, local_vars_configuration=None):  # noqa: E501
        """ChannelReturnLineResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._channel_product_no = None
        self._merchant_product_no = None
        self._accepted_quantity = None
        self._rejected_quantity = None
        self._order_line = None
        self._shipment_status = None
        self._quantity = None
        self.discriminator = None

        self.channel_product_no = channel_product_no
        self.merchant_product_no = merchant_product_no
        self.accepted_quantity = accepted_quantity
        self.rejected_quantity = rejected_quantity
        self.order_line = order_line
        self.shipment_status = shipment_status
        self.quantity = quantity

    @property
    def channel_product_no(self):
        """Gets the channel_product_no of this ChannelReturnLineResponse.  # noqa: E501

        The unique product reference used by the Channel.  # noqa: E501

        :return: The channel_product_no of this ChannelReturnLineResponse.  # noqa: E501
        :rtype: str
        """
        return self._channel_product_no

    @channel_product_no.setter
    def channel_product_no(self, channel_product_no):
        """Sets the channel_product_no of this ChannelReturnLineResponse.

        The unique product reference used by the Channel.  # noqa: E501

        :param channel_product_no: The channel_product_no of this ChannelReturnLineResponse.  # noqa: E501
        :type channel_product_no: str
        """
        if self.local_vars_configuration.client_side_validation and channel_product_no is None:  # noqa: E501
            raise ValueError("Invalid value for `channel_product_no`, must not be `None`")  # noqa: E501

        self._channel_product_no = channel_product_no

    @property
    def merchant_product_no(self):
        """Gets the merchant_product_no of this ChannelReturnLineResponse.  # noqa: E501

        The unique product reference used by the Merchant.  # noqa: E501

        :return: The merchant_product_no of this ChannelReturnLineResponse.  # noqa: E501
        :rtype: str
        """
        return self._merchant_product_no

    @merchant_product_no.setter
    def merchant_product_no(self, merchant_product_no):
        """Sets the merchant_product_no of this ChannelReturnLineResponse.

        The unique product reference used by the Merchant.  # noqa: E501

        :param merchant_product_no: The merchant_product_no of this ChannelReturnLineResponse.  # noqa: E501
        :type merchant_product_no: str
        """

        self._merchant_product_no = merchant_product_no

    @property
    def accepted_quantity(self):
        """Gets the accepted_quantity of this ChannelReturnLineResponse.  # noqa: E501

        The number of accepted items of the product in this return (should normally be refunded).  # noqa: E501

        :return: The accepted_quantity of this ChannelReturnLineResponse.  # noqa: E501
        :rtype: int
        """
        return self._accepted_quantity

    @accepted_quantity.setter
    def accepted_quantity(self, accepted_quantity):
        """Sets the accepted_quantity of this ChannelReturnLineResponse.

        The number of accepted items of the product in this return (should normally be refunded).  # noqa: E501

        :param accepted_quantity: The accepted_quantity of this ChannelReturnLineResponse.  # noqa: E501
        :type accepted_quantity: int
        """

        self._accepted_quantity = accepted_quantity

    @property
    def rejected_quantity(self):
        """Gets the rejected_quantity of this ChannelReturnLineResponse.  # noqa: E501

        The number of rejected items of the product in this return (should normally not be refunded).  # noqa: E501

        :return: The rejected_quantity of this ChannelReturnLineResponse.  # noqa: E501
        :rtype: int
        """
        return self._rejected_quantity

    @rejected_quantity.setter
    def rejected_quantity(self, rejected_quantity):
        """Sets the rejected_quantity of this ChannelReturnLineResponse.

        The number of rejected items of the product in this return (should normally not be refunded).  # noqa: E501

        :param rejected_quantity: The rejected_quantity of this ChannelReturnLineResponse.  # noqa: E501
        :type rejected_quantity: int
        """

        self._rejected_quantity = rejected_quantity

    @property
    def order_line(self):
        """Gets the order_line of this ChannelReturnLineResponse.  # noqa: E501

        The order line of the product for the return line.  # noqa: E501

        :return: The order_line of this ChannelReturnLineResponse.  # noqa: E501
        :rtype: ChannelOrderLineResponse
        """
        return self._order_line

    @order_line.setter
    def order_line(self, order_line):
        """Sets the order_line of this ChannelReturnLineResponse.

        The order line of the product for the return line.  # noqa: E501

        :param order_line: The order_line of this ChannelReturnLineResponse.  # noqa: E501
        :type order_line: ChannelOrderLineResponse
        """

        self._order_line = order_line

    @property
    def shipment_status(self):
        """Gets the shipment_status of this ChannelReturnLineResponse.  # noqa: E501

        The status of the product in relation to the shipment.  # noqa: E501

        :return: The shipment_status of this ChannelReturnLineResponse.  # noqa: E501
        :rtype: ShipmentLineStatus
        """
        return self._shipment_status

    @shipment_status.setter
    def shipment_status(self, shipment_status):
        """Sets the shipment_status of this ChannelReturnLineResponse.

        The status of the product in relation to the shipment.  # noqa: E501

        :param shipment_status: The shipment_status of this ChannelReturnLineResponse.  # noqa: E501
        :type shipment_status: ShipmentLineStatus
        """

        self._shipment_status = shipment_status

    @property
    def quantity(self):
        """Gets the quantity of this ChannelReturnLineResponse.  # noqa: E501

        Number of items of the product in this return.  # noqa: E501

        :return: The quantity of this ChannelReturnLineResponse.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this ChannelReturnLineResponse.

        Number of items of the product in this return.  # noqa: E501

        :param quantity: The quantity of this ChannelReturnLineResponse.  # noqa: E501
        :type quantity: int
        """
        if self.local_vars_configuration.client_side_validation and quantity is None:  # noqa: E501
            raise ValueError("Invalid value for `quantity`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                quantity is not None and quantity < 0):  # noqa: E501
            raise ValueError("Invalid value for `quantity`, must be a value greater than or equal to `0`")  # noqa: E501

        self._quantity = quantity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChannelReturnLineResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChannelReturnLineResponse):
            return True

        return self.to_dict() != other.to_dict()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from channelengine_channel_api_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from channelengine_channel_api_client.model.api_response import ApiResponse
from channelengine_channel_api_client.model.channel_address_request import ChannelAddressRequest
from channelengine_channel_api_client.model.channel_cancellation_line_response import ChannelCancellationLineResponse
from channelengine_channel_api_client.model.channel_cancellation_response import ChannelCancellationResponse
from channelengine_channel_api_client.model.channel_offer_response import ChannelOfferResponse
from channelengine_channel_api_client.model.channel_order_line_request import ChannelOrderLineRequest
from channelengine_channel_api_client.model.channel_order_line_response import ChannelOrderLineResponse
from channelengine_channel_api_client.model.channel_order_request import ChannelOrderRequest
from channelengine_channel_api_client.model.channel_processed_changes_request import ChannelProcessedChangesRequest
from channelengine_channel_api_client.model.channel_product_changes_response import ChannelProductChangesResponse
from channelengine_channel_api_client.model.channel_product_extra_data_item_response import ChannelProductExtraDataItemResponse
from channelengine_channel_api_client.model.channel_product_references_request import ChannelProductReferencesRequest
from channelengine_channel_api_client.model.channel_product_response import ChannelProductResponse
from channelengine_channel_api_client.model.channel_return_line_request import ChannelReturnLineRequest
from channelengine_channel_api_client.model.channel_return_line_response import ChannelReturnLineResponse
from channelengine_channel_api_client.model.channel_return_request import ChannelReturnRequest
from channelengine_channel_api_client.model.channel_return_response import ChannelReturnResponse
from channelengine_channel_api_client.model.channel_return_status import ChannelReturnStatus
from channelengine_channel_api_client.model.channel_shipment_line_response import ChannelShipmentLineResponse
from channelengine_channel_api_client.model.channel_shipment_response import ChannelShipmentResponse
from channelengine_channel_api_client.model.collection_changes_of_channel_product_changes_response import CollectionChangesOfChannelProductChangesResponse
from channelengine_channel_api_client.model.collection_of_channel_cancellation_response import CollectionOfChannelCancellationResponse
from channelengine_channel_api_client.model.collection_of_channel_offer_response import CollectionOfChannelOfferResponse
from channelengine_channel_api_client.model.collection_of_channel_return_response import CollectionOfChannelReturnResponse
from channelengine_channel_api_client.model.collection_of_channel_shipment_response import CollectionOfChannelShipmentResponse
from channelengine_channel_api_client.model.condition import Condition
from channelengine_channel_api_client.model.data_changes_product_type import DataChangesProductType
from channelengine_channel_api_client.model.extra_data_type import ExtraDataType
from channelengine_channel_api_client.model.gender import Gender
from channelengine_channel_api_client.model.json_patch_document import JsonPatchDocument
from channelengine_channel_api_client.model.manco_reason import MancoReason
from channelengine_channel_api_client.model.operation import Operation
from channelengine_channel_api_client.model.order_status_view import OrderStatusView
from channelengine_channel_api_client.model.product_type import ProductType
from channelengine_channel_api_client.model.return_reason import ReturnReason
from channelengine_channel_api_client.model.return_status import ReturnStatus
from channelengine_channel_api_client.model.shipment_line_status import ShipmentLineStatus
from channelengine_channel_api_client.model.vat_rate_type import VatRateType
